@@ -2,4 +2,4 @@ import simplex
 
 
 def main():
-    return simplex.dsimplex()
+    simplex.dsimplex()
